#include "wifi_check.h"
#include "wifi.h"
#include "ets_sys.h"
#include "osapi.h"
#include "driver\i2s.h"
#include "user_interface.h"
#include <os_type.h>
#include <espconn.h>


extern int ets_uart_printf(const char *fmt, ...);
int (*console_printf)(const char *fmt, ...) = ets_uart_printf;


LOCAL void ICACHE_FLASH_ATTR show_info(void) {
    ets_uart_printf("\nSystem info:\n");
    ets_uart_printf("SDK version: %s\n", system_get_sdk_version());
    ets_uart_printf("Time = %ld\n", system_get_time());
    ets_uart_printf("Chip id = 0x%x\n", system_get_chip_id());
    ets_uart_printf("Free heap size = %d\n", system_get_free_heap_size());
    ets_uart_printf("==========================================\n");
}

void user_rf_pre_init(void)
{
}

void user_init(void) {
    // Configure the UART
    uart_init(230400, 230400);
    os_delay_us(1000);

    // Enable system messages
    system_set_os_print(1);
    os_printf("\r\nSystem init...\r\n");
    show_info();

    if(wifi_get_opmode() != STATION_MODE) {
        os_printf("ESP8266 is %s mode, restarting in %s mode...\r\n", WiFiMode[wifi_get_opmode()], WiFiMode[STATION_MODE]);
        setup_wifi_st_mode();
    }

    wifi_check_init();

    rtp_rx_init();

    i2s_run();
}

